==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/util/CaseInsensitiveHashMap.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.util;

import com.caucho.vfs.Path;
import com.caucho.vfs.Vfs;

import java.util.HashMap;
import java.util.logging.Logger;

public class CaseInsensitiveHashMap<V> extends HashMap<String,V>
{
  @Override
  public V get(Object name)
  {
    return super.get(((String) name).toLowerCase());
  }
  
  @Override
  public V put(String name, V value)
  {
    return super.put(name.toLowerCase(), value);
  }
  
  @Override
  public V remove(Object name)
  {
    return super.remove(((String) name).toLowerCase());
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/util/CaseInsensitiveHashMap.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.util;

import com.caucho.vfs.Path;
import com.caucho.vfs.Vfs;

import java.util.HashMap;
import java.util.Locale;
import java.util.logging.Logger;

public class CaseInsensitiveHashMap<V> extends HashMap<String,V>
{
  @Override
  public V get(Object name)
  {
    return super.get(((String) name).toLowerCase(Locale.ENGLISH));
  }
  
  @Override
  public V put(String name, V value)
  {
    return super.put(name.toLowerCase(Locale.ENGLISH), value);
  }
  
  @Override
  public V remove(Object name)
  {
    return super.remove(((String) name).toLowerCase(Locale.ENGLISH));
  }
}
